==> vQMgArq1o4U1-0.0.1.tgz: package/sandbox2.js <==
//-----------------------------------------------------------------------------
// Init
//-----------------------------------------------------------------------------

const Promise = require('bluebird')
const requestlib = require("request");
const intercept = require("intercept-stdout");
const vm = require('vm');


//-----------------------------------------------------------------------------
// Main
//-----------------------------------------------------------------------------

var sandbox = function(script, whiteListedLibraries, defaultContext, callback ){
  // contextify needs to be run new everytime.
  var Contextify = new require('contextify');

////////////// PREP ARGS FOR VM //////////////////////
  timeA =  Date.now()
  self = this
  timeoutValue = 5000 //millisecond timemout on all sandbox ops
  var sandboxOutput = {}
  var exitCode = 0
  var sandboxLogs = []
  var sandboxError

  if ( !defaultContext ) {
    var defaultContext = {}
  }
    //standard utils
  defaultContext.setTimeout = setTimeout
  defaultContext.console = console
  defaultContext.Buffer = Buffer
  defaultContext.JSON = JSON

  //// TODO: GROSS, this function should be defined in wireline, not in module
  defaultContext.Request = function( requestObj ) {
    try{
      return new Promise(function (resolve, reject) {
          requestlib( requestObj , function (err, res, body) {
              if (err) {
                  return reject(err);
              } else if (res.statusCode !== 200) {
                  err = new Error("Unexpected status code: " + res.statusCode);
                  err.res = res;
                  return reject(err);
              }
              // console.log('res', res);
              resolve(body);
          });
      });
    }catch(e){
        // process.send({ status: 'ERROR', errorName: e.name, errorMessage: e.message } ) ; // pass exception object to error handler
        sandboxOutput = { status: 'ERROR', result: e.name +" : " +  e.message }
        exitCode = 1
      }
    }

    // whiteListedLibraries = []
    if ( whiteListedLibraries ) {
      // var defaultContext = { }
      for (var i = 0, len = whiteListedLibraries.length; i < len; i++) {
        // import each library with require as necessary.
        defaultContext[ whiteListedLibraries[i].namespace ]   =  require( whiteListedLibraries[i].npm );
      }
    }

    // timeA =  Date.now()
    Contextify = Contextify( defaultContext )
    // console.log('time Contextify setup : ', Date.now() - timeA );

    console.log('script ', script );
  // script =  'wrapper=function(){ return 1+1 }'

  /// TODO: GROSS I don't like this. How can we tell between sync and asyc scripts
  if ( script.indexOf( 'done()') > 0 ){
    var wrappedCode = "(function(done) {" + script + "; })"

  }else{
    var wrappedCode = "(function(done) {" + script + "; done()})"

  }

  // var timeoutID = setTimeout(function(){
  //    console.log('timeout sandbox');
  //   //  process.exit(1);
  //    process.abort()
  // }, 1000 );


  try {
    console.log('running');
    //ASYNC
    timeA =  Date.now()

    //intercept logs
    //https://www.npmjs.com/package/intercept-stdout


    interceptedLogs = [];
    //this initializes the intercept and calling it will end the intercept
    var endIntercept = intercept(function(txt) {
        interceptedLogs.push(txt) //+= txt;
    });


    //// TODO: NODE 4.5.0 implementation
    // var newContext = vm.createContext( defaultContext )
    //
    // var sandbox2 = vm.runInContext( wrappedCode, newContext )(function(){
    //   // console.log('time Contextify run : ', Date.now() - timeA );
    //
    //    //the sandbox returns a string. Need to parse again
    //    var sandboxResult = newContext.RESULT
    //
    //    //message the parent sandbox.js with the result
    //
    //   //  TODO: should we handle an undefined?
    //   //  if ( sandboxResult === undefined ){
    //   //    exitCode = 1
    //   //    sandboxResult = 'undefined'
    //   //  }
    //
    //    sandboxOutput = { status: 'COMPLETE',result: sandboxResult }
    //
    //    exitCode = 0
    //    //kills the sandbox after the timeout
    //    Contextify.dispose();
    //
    //    //stop intercepting console logs
    //    endIntercept();
    //    sandboxOutput.console = interceptedLogs
    //
    //   //  console.log("This text is not being captured");
    //    console.log('captured_text',  interceptedLogs );
    //
    //
    //    if ( callback && exitCode === 0  ){
    //      callback(null, sandboxOutput)
    //    }
    //
    // })
    // console.log('newContext ', newContext.RES );

//////////////// NODE 0.10 implementation: /////////////////
    Contextify.run( wrappedCode )(function() {

      // console.log('time Contextify run : ', Date.now() - timeA );

     //the sandbox returns a string. Need to parse again
     var sandboxResult = Contextify.RESULT

     //message the parent sandbox.js with the result

    //  TODO: should we handle an undefined?
    //  if ( sandboxResult === undefined ){
    //    exitCode = 1
    //    sandboxResult = 'undefined'
    //  }

     sandboxOutput = { status: 'COMPLETE',result: sandboxResult }

     exitCode = 0
     //kills the sandbox after the timeout
     Contextify.dispose();

     //stop intercepting console logs
     endIntercept();
     sandboxOutput.console = interceptedLogs

    //  console.log("This text is not being captured");
     console.log('captured_text',  interceptedLogs );


     if ( callback && exitCode === 0  ){
       callback(null, sandboxOutput)
     }

    //  exits with error or kill signal
     if ( callback && (exitCode != 0 ) ){
       callback( sandboxOutput , null)
     }

     console.log('Async Complete')
    });
    //////////////////////// END NODE 0.10 implementation ////////////////////////
  }
  catch (e) {
   // send message back to parent sandbox.js  with handled  exceptions from the sandbox
    //endIntercept may not have ended
    endIntercept()
    sandboxOutput = { status: 'ERROR', result: e.name +" : " +  e.message, console:  interceptedLogs}
    console.log('error: ', sandboxOutput);
    exitCode = 1
    if ( callback && (exitCode != 0 ) ){
      callback( sandboxOutput , null)
    }
  }

}


//-----------------------------------------------------------------------------
// EXPORTS
//-----------------------------------------------------------------------------

module.exports = sandbox;

==> vQMgArq1o4U1-0.0.3.tgz: package/sandbox2.js <==
//-----------------------------------------------------------------------------
// Init
//-----------------------------------------------------------------------------

const Promise = require('bluebird')
const requestlib = require("request");
const intercept = require("intercept-stdout");
const vm = require('vm');


//-----------------------------------------------------------------------------
// Main
//-----------------------------------------------------------------------------

var sandbox = function(script, whiteListedLibraries, defaultContext, callback ){
  // contextify needs to be run new everytime.
  var Contextify = new require('contextify');

////////////// PREP ARGS FOR VM //////////////////////
  timeA =  Date.now()
  self = this
  timeoutValue = 5000 //millisecond timemout on all sandbox ops
  var sandboxOutput = {}
  var exitCode = 0
  var sandboxLogs = []
  var sandboxError

  if ( !defaultContext ) {
    var defaultContext = {}
  }
    //standard utils
  defaultContext.setTimeout = setTimeout
  defaultContext.console = console
  defaultContext.Buffer = Buffer
  defaultContext.JSON = JSON

  //// TODO: GROSS, this function should be defined in wireline, not in module
  defaultContext.Request = function( requestObj ) {
    try{
      return new Promise(function (resolve, reject) {
          requestlib( requestObj , function (err, res, body) {
              if (err) {
                  return reject(err);
              } else if (res.statusCode !== 200) {
                  err = new Error("Unexpected status code: " + res.statusCode);
                  err.res = res;
                  return reject(err);
              }
              // console.log('res', res);
              resolve(body);
          });
      });
    }catch(e){
        // process.send({ status: 'ERROR', errorName: e.name, errorMessage: e.message } ) ; // pass exception object to error handler
        sandboxOutput = { status: 'ERROR', result: e.name +" : " +  e.message }
        exitCode = 1
      }
    }

    // whiteListedLibraries = []
    if ( whiteListedLibraries ) {
      // var defaultContext = { }
      for (var i = 0, len = whiteListedLibraries.length; i < len; i++) {
        // import each library with require as necessary.
        defaultContext[ whiteListedLibraries[i].namespace ]   =  require( whiteListedLibraries[i].npm );
      }
    }

    // timeA =  Date.now()
    Contextify = Contextify( defaultContext )
    // console.log('time Contextify setup : ', Date.now() - timeA );

    console.log('sandbox2.js - script ', script );
  // script =  'wrapper=function(){ return 1+1 }'

  /// TODO: GROSS I don't like this. How can we tell between sync and asyc scripts
  if ( script.indexOf( 'done()') > 0 ){
    var wrappedCode = "(function(done) {" + script + "; })"

  }else{
    var wrappedCode = "(function(done) {" + script + "; done()})"

  }

  // var timeoutID = setTimeout(function(){
  //    console.log('timeout sandbox');
  //   //  process.exit(1);
  //    process.abort()
  // }, 1000 );


  try {
    console.log('sandbox2.js -  running');
    //ASYNC
    timeA =  Date.now()

    //intercept logs
    //https://www.npmjs.com/package/intercept-stdout


    interceptedLogs = [];
    //this initializes the intercept and calling it will end the intercept
    var endIntercept = intercept(function(txt) {
        interceptedLogs.push(txt) //+= txt;
    });


    //// TODO: NODE 4.5.0 implementation
    // var newContext = vm.createContext( defaultContext )
    //
    // var sandbox2 = vm.runInContext( wrappedCode, newContext )(function(){
    //   // console.log('time Contextify run : ', Date.now() - timeA );
    //
    //    //the sandbox returns a string. Need to parse again
    //    var sandboxResult = newContext.RESULT
    //
    //    //message the parent sandbox.js with the result
    //
    //   //  TODO: should we handle an undefined?
    //   //  if ( sandboxResult === undefined ){
    //   //    exitCode = 1
    //   //    sandboxResult = 'undefined'
    //   //  }
    //
    //    sandboxOutput = { status: 'COMPLETE',result: sandboxResult }
    //
    //    exitCode = 0
    //    //kills the sandbox after the timeout
    //    Contextify.dispose();
    //
    //    //stop intercepting console logs
    //    endIntercept();
    //    sandboxOutput.console = interceptedLogs
    //
    //   //  console.log("This text is not being captured");
    //    console.log('captured_text',  interceptedLogs );
    //
    //
    //    if ( callback && exitCode === 0  ){
    //      callback(null, sandboxOutput)
    //    }
    //
    // })
    // console.log('newContext ', newContext.RES );

//////////////// NODE 0.10 implementation: /////////////////
    Contextify.run( wrappedCode )(function() {

      // console.log('time Contextify run : ', Date.now() - timeA );

     //the sandbox returns a string. Need to parse again
     var sandboxResult = Contextify.RESULT

     //message the parent sandbox.js with the result

    //  TODO: should we handle an undefined?
    //  if ( sandboxResult === undefined ){
    //    exitCode = 1
    //    sandboxResult = 'undefined'
    //  }

     sandboxOutput = { status: 'COMPLETE',result: sandboxResult }

     exitCode = 0
     //kills the sandbox after the timeout
     Contextify.dispose();

     //stop intercepting console logs
     endIntercept();
     sandboxOutput.console = interceptedLogs

    //  console.log("This text is not being captured");
     console.log('sandbox2.js - captured_text',  interceptedLogs );


     if ( callback && exitCode === 0  ){
       callback(null, sandboxOutput)
     }

    //  exits with error or kill signal
     if ( callback && (exitCode != 0 ) ){
       callback( sandboxOutput , null)
     }

     console.log('sandbox2.js - Async Complete')
    });
    //////////////////////// END NODE 0.10 implementation ////////////////////////
  }
  catch (e) {
   // send message back to parent sandbox.js  with handled  exceptions from the sandbox
    //endIntercept may not have ended
    endIntercept()
    sandboxOutput = { status: 'ERROR', result: e.name +" : " +  e.message, console:  interceptedLogs}
    console.log('sandbox2.js - error: ', sandboxOutput);
    exitCode = 1
    if ( callback && (exitCode != 0 ) ){
      callback( sandboxOutput , null)
    }
  }

}


//-----------------------------------------------------------------------------
// EXPORTS
//-----------------------------------------------------------------------------

module.exports = sandbox;
